# -*- coding: utf-8 -*-
# mdx-journal (c) 2014-2016 Ian Dennis Miller

__version__ = '0.1.4'
__author__ = 'Ian Dennis Miller'
__email__ = 'iandennismiller@gmail.com'
__url__ = 'https://github.com/iandennismiller/mdx_journal'
__copyright__ = '2013-2016, Ian Dennis Miller'
